@@ -265,6 +265,26 @@ extern char *optarg;
 /*
  * Local variables
  */
+
+/* This fixes ambiguities on platforms that don't distinguish extern case */
+#ifdef CASE_PROBLEM
+#	define txt_help_B	txt_help_BIGB
+#	define txt_help_D	txt_help_BIGD
+#	define txt_help_I	txt_help_BIGI
+#	define txt_help_K	txt_help_BIGK
+#	define txt_help_L	txt_help_BIGL
+#	define txt_help_M	txt_help_BIGM
+#	define txt_help_Q	txt_help_BIGQ
+#	define txt_help_S	txt_help_BIGS
+#	define txt_help_T	txt_help_BIGT
+#	define txt_help_U	txt_help_BIGU
+#	define txt_help_W	txt_help_BIGW
+#	define txt_help_X	txt_help_BIGX
+#	define txt_help_p_S	txt_help_p_BIGS
+#	define txt_help_t_K	txt_help_t_BIGK
+#	define txt_help_thd_C	txt_help_thd_BIGC
+#endif /* CASE_PROBLEM */
+
 extern FILE *note_fp;				/* body of current article */
 extern char **news_headers_to_display_array;
 extern char **news_headers_to_not_display_array;
@@ -285,7 +305,6 @@ extern char default_organization[PATH_LEN];
 extern char default_signature[PATH_LEN];
 extern char global_attributes_file[PATH_LEN];
 extern char global_config_file[PATH_LEN];
-extern char global_filter_file[PATH_LEN];
 extern char homedir[PATH_LEN];
 extern char index_maildir[PATH_LEN];
 extern char index_newsdir[PATH_LEN];
@@ -295,7 +314,7 @@ extern char last_put[];
 extern char libdir[PATH_LEN];
 extern char local_attributes_file[PATH_LEN];
 extern char local_config_file[PATH_LEN];
-extern char local_filter_file[PATH_LEN];
+extern char filter_file[PATH_LEN];
 extern char local_input_history_file[PATH_LEN];
 extern char local_newsgroups_file[PATH_LEN];
 extern char local_newsrctable_file[PATH_LEN];
@@ -728,6 +747,9 @@ extern constext txt_newsrc_nogroups[];
 extern constext txt_newsrc_saved[];
 extern constext txt_next_resp[];
 extern constext txt_nntp_authorization_failed[];
+#ifdef NNTP_ABLE
+	extern constext txt_nntp_ok_goodbye[];
+#endif /* NNTP_ABLE */
 extern constext txt_no[];
 extern constext txt_no_arts[];
 extern constext txt_no_arts_posted[];
@@ -1038,10 +1060,9 @@ extern t_bool disable_gnksa_domain_check;
 extern t_bool disable_sender;
 extern t_bool do_rfc1521_decoding;
 extern t_bool force_reread_active_file;
-extern t_bool global_filtered_articles;
 extern t_bool got_sig_pipe;
 extern t_bool in_headers; /* colorful headers */
-extern t_bool local_filtered_articles;
+extern t_bool filtered_articles;
 extern t_bool local_index;
 extern t_bool mail_news;
 extern t_bool list_active;
@@ -1134,41 +1155,6 @@ extern char *input_history[HIST_MAXNUM+1][HIST_SIZE+1];
 #define GNKSA_ADDRTYPE_ROUTE	0
 #define GNKSA_ADDRTYPE_OLDSTYLE	1
 
-/* This fixes ambiguities on platforms that don't distinguish extern case */
-#ifdef CASE_PROBLEM
-#	define txt_help_B	txt_help_BIGB
-#	define txt_help_D	txt_help_BIGD
-#	define txt_help_I	txt_help_BIGI
-#	define txt_help_K	txt_help_BIGK
-#	define txt_help_L	txt_help_BIGL
-#	define txt_help_M	txt_help_BIGM
-#	define txt_help_Q	txt_help_BIGQ
-#	define txt_help_S	txt_help_BIGS
-#	define txt_help_T	txt_help_BIGT
-#	define txt_help_U	txt_help_BIGU
-#	define txt_help_W	txt_help_BIGW
-#	define txt_help_X	txt_help_BIGX
-#	define txt_help_p_S	txt_help_p_BIGS
-#	define txt_help_t_K	txt_help_t_BIGK
-#endif /* CASE_PROBLEM */
-
-#ifdef VMS /* M.St. 15.01.98 */
-	extern constext txt_help_BIGB[];
-	extern constext txt_help_BIGD[];
-	extern constext txt_help_BIGI[];
-	extern constext txt_help_BIGK[];
-	extern constext txt_help_BIGL[];
-	extern constext txt_help_BIGM[];
-	extern constext txt_help_BIGQ[];
-	extern constext txt_help_BIGS[];
-	extern constext txt_help_BIGT[];
-	extern constext txt_help_BIGU[];
-	extern constext txt_help_BIGW[];
-	extern constext txt_help_BIGX[];
-	extern constext txt_help_p_BIGS[];
-	extern constext txt_help_t_BIGK[];
-#endif /* VMS */
-
 #ifndef DONT_HAVE_PIPING
 	extern constext txt_pipe[];
 	extern constext txt_pipe_to_command[];
