@@ -1,6 +1,11 @@
 #ifndef PROTO_H
 #	define PROTO_H 1
 
+#ifdef CASE_PROBLEM
+#	define Raw	tin_Raw
+#	define EndWin	tin_EndWin
+#endif
+
 /* active.c */
 extern int get_active_num (void);
 extern char group_flag (int ch);
@@ -37,7 +42,7 @@ extern void vWriteNovFile (struct t_group *psGrp);
 
 /* auth.c */
 #if !defined (INDEX_DAEMON) && defined (NNTP_ABLE)
-	extern t_bool authenticate (char *server, int respcode, char *user, t_bool startup);
+	extern t_bool authenticate (char *server, char *user, t_bool startup);
 #endif /* !INDEX_DAEMON && NNTP_ABLE */
 
 /* charset.c */
@@ -129,7 +134,7 @@ extern t_bool quick_filter (int type, struct t_group *group, struct t_article *a
 extern t_bool quick_filter_select_posted_art (struct t_group *group, char *subj);
 extern void free_all_filter_arrays (void);
 #ifndef INDEX_DAEMON
-	extern t_bool read_filter_file (char *file, t_bool global_file);
+	extern t_bool read_filter_file (char *file);
 #endif /* !INDEX_DAEMON */
 
 /* getline.c */
@@ -194,6 +199,9 @@ extern void postinit_regexp (void);
 /* joinpath.c */
 extern void joinpath (char *result, const char *dir, const char *file);
 
+/* lang.c */
+extern char *tin_version (void);
+
 /* list.c */
 extern int find_group_index (const char *group);
 extern struct t_group *psGrpAdd (char *group);
@@ -540,6 +548,7 @@ extern RETSIGTYPE (*sigdisp (int sig, RETSIGTYPE (*func)(SIG_ARGS))) (SIG_ARGS);
 extern t_bool set_win_size (int *num_lines, int *num_cols);
 extern void allow_resize(t_bool allow);
 extern void handle_resize (t_bool repaint);
+extern void set_noteslines (int num_lines);
 extern void set_signal_catcher (int flag);
 extern void set_signal_handlers (void);
 extern void set_signals_art (void);
@@ -563,7 +572,7 @@ extern int sh_format (char *dst, size_t len, const char *fmt, ...);
 extern size_t mystrcat (char **t, const char *s);
 extern void modifiedstrncpy (char *target, const char *source, size_t size, int decode);
 extern void my_strncpy (char *p, const char *q, size_t n);
-extern void str_lwr (char *dst, const char *src);
+extern void str_lwr (char *str);
 extern void strcpynl (char *to, const char *from);
 #ifndef HAVE_STRPBRK
 	extern char *strpbrk (char *str1, char *str2);
