@@ -3,7 +3,7 @@
  *  Module    : inews.c
  *  Author    : I. Lea
  *  Created   : 1992-03-17
- *  Updated   : 1999-11-29
+ *  Updated   : 1997-12-31
  *  Notes     : NNTP builtin version of inews
  *  Copyright : (c) Copyright 1991-99 by Iain Lea
  *              You may  freely  copy or  redistribute  this software,
@@ -67,8 +67,8 @@ submit_inews (
 {
 	FILE *fp;
 	char *ptr;
-	char from_name[PATH_LEN];
-	char message_id[PATH_LEN];
+	char from_name[HEADER_LEN];
+	char message_id[HEADER_LEN];
 	char line[NNTP_STRLEN];
 	int auth_error = 0;
 	int respcode;
@@ -76,6 +76,7 @@ submit_inews (
 	t_bool id_in_article = FALSE;
 	t_bool ret_code = FALSE;
 #	ifndef FORGERY
+	char sender_hdr[HEADER_LEN];
 	int sender = 0;
 	t_bool ismail = FALSE;
 #	endif /* !FORGERY */
@@ -92,7 +93,7 @@ submit_inews (
 		if (line[0] != '\n') {
 			ptr = strchr (line, ':');
 			if (ptr - line == 4 && !strncasecmp (line, "From", 4)) {
-				strcpy(from_name, ptr+2);
+				strcpy(from_name, line);
 				if ((ptr = strchr(from_name, '\n')))
 					*ptr = '\0';
 			}
@@ -106,7 +107,7 @@ submit_inews (
 			break; /* end of headers */
 	}
 
-	if (from_name[0] == '\0') {
+	if ((from_name[0] == '\0') || (from_name[6] == '\0')) {
 		/* we could silently add a From: line here if we want to... */
 		error_message (txt_error_no_from);
 		fclose (fp);
@@ -117,18 +118,50 @@ submit_inews (
 	 *
 	 * this will be done once again in sender_needed!?!
 	 */
-	if (GNKSA_OK != gnksa_check_from(rfc1522_encode(from_name, FALSE))) { /* error in address */
+#ifndef FORGERY
+	if (GNKSA_OK != gnksa_check_from(rfc1522_encode(from_name, FALSE) + 6)) { /* error in address */
 		error_message (txt_invalid_from, from_name);
 		fclose (fp);
 		return ret_code;
 	}
-
-	/*
-	 * Send POST command to NNTP server
-	 * Receive CONT_POST or ERROR response code from NNTP server
-	 */
+#endif /* !FORGERY */
 	do {
 		rewind(fp);
+
+
+#	ifndef FORGERY
+		if ((ptr = build_sender()) && (!disable_sender)) {
+			sender = sender_needed (from_name + 6, ptr);
+			switch (sender) {
+				case -2: /* can't build Sender: */
+					error_message (txt_invalid_sender, ptr);
+					fclose (fp);
+					return ret_code;
+					/* NOTREACHED */
+					break;
+
+				case -1: /* illegal From: (can't happen as check is done above allready) */
+					error_message (txt_invalid_from, from_name + 6);
+					fclose (fp);
+					return ret_code;
+					/* NOTREACHED */
+					break;
+
+				case 1:	/* insert Sender */
+					sprintf (sender_hdr, "Sender: %s", rfc1522_encode(ptr, ismail));
+					break;
+
+				case 0: /* no sender needed */
+				default:
+					break;
+			}
+		}
+#	endif /* !FORGERY */
+
+		/*
+		 * Send POST command to NNTP server
+		 * Receive CONT_POST or ERROR response code from NNTP server
+		 */
 		if (nntp_command("POST", CONT_POST, line) == NULL) {
 			error_message ("%s", line);
 			fclose (fp);
@@ -157,40 +190,15 @@ submit_inews (
 			}
 		}
 
-		/*
-		 * Send Path: and From: article headers
-		 */
 #	ifndef FORGERY
+		/*
+		 * Send Path: (and Sender: if needed) headers
+		 */
 		sprintf (line, "Path: %s", PATHMASTER);
 		put_server (line);
 
-		if ((ptr = build_sender()) && (!disable_sender)) {
-			sender = sender_needed(rfc1522_decode(from_name), ptr);
-			switch (sender) {
-				case -2: /* can't build Sender: */
-					error_message (txt_invalid_sender, ptr);
-					fclose (fp);
-					return ret_code;
-					/* NOTREACHED */
-					break;
-
-				case -1: /* illegal From: (can't happen as check is done above allready) */
-					error_message (txt_invalid_from, from_name);
-					fclose (fp);
-					return ret_code;
-					/* NOTREACHED */
-					break;
-
-				case 1:	/* insert Sender */
-					sprintf (line, "Sender: %s", rfc1522_encode(ptr, ismail));
-					put_server (line);
-					break;
-
-				case 0: /* no sender needed */
-				default:
-					break;
-			}
-		}
+		if (sender == 1)
+			put_server (sender_hdr);
 #	endif /* !FORGERY */
 
 		/*
@@ -202,7 +210,7 @@ submit_inews (
 				put_server (line);
 			}
 #	ifdef USE_CANLOCK
-				/* create a Cancel-Lock: */
+			/* create a Cancel-Lock: */
 			{
 				char lock[1024];
 				const char *lptr = (const char *) 0;
@@ -265,10 +273,7 @@ submit_inews (
 		 * authentication request was received. Leave loop on any other
 		 * response or any further authentication requests.
 		 */
-		if (((respcode == ERR_NOAUTH)       || 
-		     (respcode == ERR_NOAUTHSIMPLE) ||
-		     (respcode == NEED_AUTHINFO)) &&
-		    (auth_error++ < 1) && (authenticate (nntp_server, respcode, userid, FALSE)))
+		if (((respcode == ERR_NOAUTH) || (respcode == NEED_AUTHINFO)) && (auth_error++ < 1) && (authenticate (nntp_server, userid, FALSE)))
 			leave_loop = FALSE;
 	} while (!leave_loop);
 
@@ -354,8 +359,10 @@ static int sender_needed (
 	char *sender_at_pos;
 	char *sender_dot_pos;
 	char from_addr[HEADER_LEN];
+	char from_line[HEADER_LEN];
 	char from_name[HEADER_LEN];
 	char sender_addr[HEADER_LEN];
+	char sender_line[HEADER_LEN];
 	char sender_name[HEADER_LEN];
 
 #ifdef DEBUG
@@ -363,7 +370,8 @@ static int sender_needed (
 		wait_message (0, "sender_needed From:=[%s]", from);
 #endif /* DEBUG */
 
-	if (GNKSA_OK != gnksa_do_check_from(rfc1522_encode(from, FALSE), from_addr, from_name))
+	sprintf (from_line, "From: %s", from);
+	if (GNKSA_OK != gnksa_do_check_from(rfc1522_encode(from_line, FALSE) + 6, from_addr, from_name))
 		return -1;
 
 #ifdef DEBUG
@@ -371,7 +379,8 @@ static int sender_needed (
 		wait_message (0, "sender_needed Sender:=[%s]", sender);
 #endif /* DEBUG */
 
-	if (GNKSA_OK != gnksa_do_check_from(rfc1522_encode(sender, FALSE), sender_addr, sender_name))
+	sprintf (sender_line, "Sender: %s", sender);
+	if (GNKSA_OK != gnksa_do_check_from(rfc1522_encode(sender_line, FALSE) + 8, sender_addr, sender_name))
 		return -2;
 
 	from_at_pos = strchr(from_addr, '@');
@@ -381,8 +390,7 @@ static int sender_needed (
 	if (strncasecmp(from_addr, sender_addr, (from_at_pos - from_addr)))
 		return 1; /* login differs */
 
-	if (strcasecmp(from_at_pos, sender_at_pos)
-	    && (strcasecmp (from_at_pos+1, sender_dot_pos+1)))
+	if (strcasecmp(from_at_pos, sender_at_pos) && (strcasecmp (from_at_pos + 1, sender_dot_pos + 1)))
 		return 1; /* domainname differs */
 
 	return 0;
