@@ -15,6 +15,9 @@
 #ifndef TIN_H
 #	include "tin.h"
 #endif /* !TIN_H */
+#ifndef VERSION_H
+#	include  "version.h"
+#endif /* !VERSION_H */
 #ifndef TCURSES_H
 #	include "tcurses.h"	/* to define cCRLF */
 #endif /* !TCURSES_H */
@@ -80,7 +83,7 @@ constext txt_cannot_write_to_directory[] = "%s is a directory";
 constext txt_catchup_all_read_groups[] = "Catchup all groups entered during this session? (y/n): ";
 constext txt_catchup_update_info[] = "%s %d group%s in %lu seconds\n";
 constext txt_check_article[] = "Check Prepared Article";
-constext txt_checking_new_groups[] = "Checking for new groups...\n";
+constext txt_checking_new_groups[] = "Checking for new groups...";
 constext txt_checking_for_news[] = "Checking for news...";
 constext txt_checksum_of_file[] = cCRLF "Checksum of %s" cCRLF;
 constext txt_return_key[] = "Press <RETURN> to continue...";
@@ -217,7 +220,7 @@ constext txt_unsubscribe_pattern[] = "Enter wildcard unsubscribe pattern> ";
 #if defined(HAVE_POLL) || defined(HAVE_SELECT)
 	constext txt_group[] = "Group %.*s ('q' to quit)... ";
 #else
-	constext txt_group[] = "Group %*s... ";
+	constext txt_group[] = "Group %.*s... ";
 #endif /* HAVE_POLL || HAVE_SELECT */
 
 constext txt_group_is_moderated[] = "Group %s is moderated. Continue? (y/n): ";
@@ -487,6 +490,9 @@ constext txt_newsrc_nogroups[] = "Warning: No newsgroups were written to your ne
 constext txt_newsrc_saved[] = "newsrc file saved successfully.\n";
 constext txt_next_resp[] = "-- Next response --";
 constext txt_nntp_authorization_failed[] = "NNTP authorization password not found for %s";
+#ifdef NNTP_ABLE
+	constext txt_nntp_ok_goodbye[] = "205  Closing connection";
+#endif /* NNTP_ABLE */
 constext txt_no[] = "No ";
 constext txt_no_arts[] = "*** No articles ***";
 constext txt_no_arts_posted[] = "No articles have been posted";
@@ -784,7 +790,7 @@ constext txt_reading_article[] = "Reading ('q' to quit)... ";
 constext txt_reading_arts[] = "Reading %sarticles...";
 constext txt_reading_attributes_file[] = "Reading %sattributes file...\n";
 constext txt_reading_config_file[] = "Reading %sconfig file...\n";
-constext txt_reading_filter_file[] = "Reading %sfilter file...\n";
+constext txt_reading_filter_file[] = "Reading filter file...\n";
 constext txt_reading_input_history_file[] = "Reading input history file...\n";
 
 #if !defined(INDEX_DAEMON) && defined(HAVE_MH_MAIL_HANDLING)
@@ -887,7 +893,7 @@ Warning: You are using a non-plain transfer encoding (such as base64 or\n\
 constext txt_warn_update[] = "\n\nYou are upgrading to tin %s from an earlier version.\n\
 Some values in your configuration file have changed!\nRead WHATSNEW, etc...\n";
 
-constext txt_warn_newsrc[] = "Warning: tin wrote less groups to your %s\n\
+constext txt_warn_newsrc[] = "Warning: tin wrote fewer groups to your %s\n\
 than it read at startup. If you didn't unsubscribe from %ld group%s during\n\
 this session this indicates an error and you should backup your %s\n\
 before you start tin once again!\n";
@@ -1030,7 +1036,7 @@ struct opttxt txt_beginner_level = {
 	"<SPACE> toggles, <CR> sets, <ESC> cancels.",
 	"Show mini menu & posting etiquette : ",
 	"# If ON show a mini menu of useful commands at each level\n\
-# and posting etiquette after composing a article\n"
+# and posting etiquette after composing an article\n"
 };
 
 struct opttxt txt_show_description = {
@@ -1855,3 +1861,10 @@ struct opttxt txt_cache_overview_files = {
 	"# If ON, create local copies of NNTP overview files.\n"
 };
 
+char *tin_version(void)
+{
+	static char result[80];
+	sprintf (result, "Version: %s release %s (\"%s\")",
+		VERSION, RELEASEDATE, RELEASENAME);
+	return result;
+}
