@@ -15,12 +15,12 @@
 #ifndef TIN_H
 #	include "tin.h"
 #endif /* !TIN_H */
-#ifndef TCURSES_H
-#	include "tcurses.h"
-#endif /* !TCURSES_H */
 #ifndef VERSION_H
 #	include  "version.h"
 #endif /* !VERSION_H */
+#ifndef TCURSES_H
+#	include "tcurses.h"
+#endif /* !TCURSES_H */
 #ifndef BUGREP_H
 #	include  "bugrep.h"
 #endif /* !BUGREP_H */
@@ -222,7 +222,11 @@ main (
 	 * Load the local & global group specific attribute files
 	 */
 #ifndef INDEX_DAEMON
+	if (INTERACTIVE)
+		wait_message (0, txt_reading_attributes_file, "global ");
 	read_attributes_file (global_attributes_file, TRUE);
+	if (INTERACTIVE)
+		wait_message (0, txt_reading_attributes_file, "");
 	read_attributes_file (local_attributes_file, FALSE);
 #endif /* !INDEX_DAEMON */
 
@@ -232,11 +236,9 @@ main (
 	 * because the filters will be updated.
 	 */
 #ifndef INDEX_DAEMON
-	global_filtered_articles = read_filter_file (global_filter_file, TRUE);
-	local_filtered_articles = read_filter_file (local_filter_file, FALSE);
+	filtered_articles = read_filter_file (filter_file);
 #else
-	global_filtered_articles = TRUE;
-	local_filtered_articles = TRUE;
+	filtered_articles = TRUE;
 #endif /* !INDEX_DAEMON */
 
 #ifdef DEBUG
@@ -581,11 +583,11 @@ read_cmd_line_options (
 
 			case 'V':
 #if defined(__DATE__) && defined(__TIME__)
-				error_message ("Version: %s release %s (\"%s\") %s %s",
-					VERSION, RELEASEDATE, RELEASENAME, __DATE__, __TIME__);
+				error_message ("%s %s %s",
+					tin_version(), __DATE__, __TIME__);
 #else
-				error_message ("Version: %s release %s (\"%s\")",
-					VERSION, RELEASEDATE, RELEASENAME);
+				error_message ("%s",
+					tin_version());
 #endif /* __DATE__  && __TIME__ */
 				exit (EXIT_SUCCESS);
 				/* keep lint quiet: */
@@ -802,13 +804,15 @@ check_for_any_new_news (
 
 	if (CheckAnyUnread) {
 		i = check_start_save_any_news (CHECK_ANY_NEWS);
+		cursoron();
+		Raw (FALSE);
 		exit (i);
 	}
 
 	if (StartAnyUnread) {
 		batch_mode = TRUE;			/* Suppress some unwanted on-screen garbage */
 		if ((i = check_start_save_any_news (START_ANY_NEWS)) == -1)
-			exit (EXIT_SUCCESS);			/* No new/unread news so exit */
+			giveup();				/* No new/unread news so exit */
 		batch_mode = FALSE;
 	}
 
