@@ -518,8 +518,7 @@ tin_done (
 #endif /* USE_DBMALLOC */
 
 #ifdef VMS
-	if (!ret)
-		ret = 1;
+	ret = !ret;
 	vms_close_stdin (); /* free resources used by ReadCh */
 #endif /* VMS */
 
@@ -753,6 +752,9 @@ invoke_cmd (
 	ret = system (nam);
 #endif /* USE_SYSTEM_STATUS */
 	TRACE(("return %d", ret))
+#ifdef VMS
+	ret = !ret;	  /* good enough to test success/fail */
+#endif
 
 	set_signal_catcher (TRUE);
 	if (!save_cmd_line) {
@@ -764,11 +766,7 @@ invoke_cmd (
 	if (ret != 0)
 		error_message (txt_command_failed, nam);
 
-#ifdef VMS
-	return ret != 0;
-#else
 	return ret == 0;
-#endif /* VMS */
 }
 
 
@@ -898,7 +896,7 @@ base_name (
 		}
 	}
 #ifdef M_OS2
-	str_lwr (program, program);
+	str_lwr (program);
 #endif /* M_OS2 */
 #ifdef VMS
 	if (cp = strrchr(program, '.'))
@@ -1969,7 +1967,7 @@ strfmailer (
 					strcpy (tbuf, "\n");
 					break;
 				default:
-					tbuf[0] = '%';
+					tbuf[0] = '\\';
 					tbuf[1] = *format;
 					tbuf[2] = '\0';
 					break;
@@ -1992,21 +1990,33 @@ strfmailer (
 					*s++ = '%';
 					continue;
 				case 'F':	/* Filename */
-					strcpy (tbuf, filename);
+					STRCPY(tbuf, filename);
 					break;
 				case 'M':	/* Mailer */
-					strcpy (tbuf, the_mailer);
+					STRCPY(tbuf, the_mailer);
 					break;
 				case 'S':	/* Subject */
-					strcpy (tbuf, escape_shell_meta (rfc1522_encode (subject, ismail) , quote_area));
+					if (tinrc.use_mailreader_i) {
+						STRCPY(tbuf, escape_shell_meta (subject, quote_area));
+					} else {
+						STRCPY(tbuf, escape_shell_meta (rfc1522_encode (subject, ismail) , quote_area));
+					}
 					escaped = TRUE;
 					break;
 				case 'T':	/* To */
-					strcpy (tbuf, escape_shell_meta (rfc1522_encode (to, ismail), quote_area));
+					if (tinrc.use_mailreader_i) {
+						STRCPY(tbuf, escape_shell_meta (to, quote_area));
+					} else {
+						STRCPY(tbuf, escape_shell_meta (rfc1522_encode (to, ismail), quote_area));
+					}
 					escaped = TRUE;
 					break;
 				case 'U':	/* User */
-					strcpy (tbuf, rfc1522_encode (userid, ismail));
+					if (tinrc.use_mailreader_i) {
+						STRCPY(tbuf, userid);
+					} else {
+						STRCPY(tbuf, rfc1522_encode (userid, ismail));
+					}
 					break;
 				default:
 					tbuf[0] = '%';
@@ -3541,3 +3551,17 @@ parse_from (
 	return gnksa_do_check_from(from, address, realname);
 }
 #endif /* 1 */
+
+/*
+ * This is a work-around for a conflict between the sleep() function with
+ * OpenVMS 6.x using socketshr.  It does not appear to be needed for
+ * executables built on OpenVMS 7.x
+ */
+#ifdef SOCKETSHR_TCP
+#	if defined(__DECC) && __CRTL_VER < 70000000
+int my_sleep(unsigned n)
+{
+	return 0;
+}
+#	endif
+#endif
