@@ -187,7 +187,9 @@ allow_resize (
 #	ifdef SIGWINCH
 	sigaction(SIGWINCH, &sa, &osa);
 #	endif /* SIGWINCH */
+#	ifdef SIGTSTP
 	sigaction(SIGTSTP, &sa, &osa);
+#	endif /* SIGTSTP */
 #endif /* HAVE_POSIX_JC */
 }
 
@@ -211,11 +213,11 @@ signal_name (
  * the current context
  * This should NOT be called from an interrupt context
  */
-#if defined(SIGWINCH) || defined(SIGTSTP)
 void
 handle_resize (
 	t_bool repaint)
 {
+#if defined(SIGWINCH) || defined(SIGTSTP)
 #	ifdef SIGWINCH
 	repaint |= set_win_size (&cLINES, &cCOLS);
 #	endif /* SIGWINCH */
@@ -274,8 +276,8 @@ handle_resize (
 			break;
 	}
 	my_fflush(stdout);
-}
 #endif /* SIGWINCH || SIGTSTP */
+}
 
 #ifdef SIGTSTP
 static void
@@ -506,9 +508,16 @@ set_win_size (
 
 	RIGHT_POS = *num_cols - 20;
 	MORE_POS  = *num_cols - 15;
-	NOTESLINES = *num_lines - INDEX_TOP - (tinrc.beginner_level ? MINI_HELP_LINES : 1);
-	if (NOTESLINES <= 0)
-		NOTESLINES = 1;
+	set_noteslines (*num_lines);
 
 	return (*num_lines != old_lines || *num_cols != old_cols);
 }
+
+void
+set_noteslines (
+	int num_lines)
+{
+	NOTESLINES = num_lines - INDEX_TOP - (tinrc.beginner_level ? MINI_HELP_LINES : 1);
+	if (NOTESLINES <= 0)
+		NOTESLINES = 1;
+}
